"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FilledGauge = FilledGauge;

var _react = _interopRequireDefault(require("react"));

var _reactNativeRedash = require("react-native-redash");

var _reactNativeReanimated = require("react-native-reanimated");

var _Track = require("./Track");

var _Animated = require("./Animated");

var _SliderContext = require("../../context/SliderContext");

var _worklets = require("../../utils/worklets");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function FilledGauge(_ref) {
  let {
    color,
    startTheta,
    endTheta
  } = _ref;
  const {
    r,
    center,
    trackWidth,
    clockwise
  } = (0, _SliderContext.useSliderContext)();

  const position = theta => {
    'worklet';

    return () => {
      'worklet';

      return (0, _reactNativeRedash.polar2Canvas)({
        theta: theta.value,
        radius: r.value
      }, center.value);
    };
  };

  const startPosition = (0, _reactNativeReanimated.useDerivedValue)(position(startTheta), [startTheta]);
  const endPosition = (0, _reactNativeReanimated.useDerivedValue)(position(endTheta), [endTheta]);

  const isFullFilled = Math.abs(startTheta.value - endTheta.value) === _reactNativeRedash.TAU;

  const animatedProps = (0, _reactNativeReanimated.useAnimatedProps)(() => {
    const {
      x: startX,
      y: startY
    } = startPosition.value;
    const {
      x: endX,
      y: endY
    } = endPosition.value;
    const theta = (0, _worklets.thetaBetweenStartAndEnd)(startTheta.value, endTheta.value);
    const large = clockwise ? theta < _reactNativeRedash.PI : theta > _reactNativeRedash.PI;
    const largeArcFlag = large ? '1' : '0';
    const sweepFlag = clockwise ? '1' : '0';
    const d = [`M ${startX} ${startY}`, `A ${r.value} ${r.value} 0 ${largeArcFlag} ${sweepFlag} ${endX} ${endY}`].join(' ');
    return {
      d,
      strokeWidth: trackWidth.value
    };
  }, [clockwise]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, isFullFilled ? /*#__PURE__*/_react.default.createElement(_Track.Track, null) : /*#__PURE__*/_react.default.createElement(_Animated.AnimatedPath, {
    "data-testid": "filled-gauge",
    stroke: color,
    animatedProps: animatedProps
  }));
}
//# sourceMappingURL=FilledGauge.js.map