"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = SliderContextProvider;
exports.useSliderContext = useSliderContext;
exports.useThumbContext = useThumbContext;
exports.useTickMarkContext = useTickMarkContext;

var _react = _interopRequireWildcard(require("react"));

var _reactNativeReanimated = require("react-native-reanimated");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const SliderContext = /*#__PURE__*/(0, _react.createContext)(null);

function SliderContextProvider(_ref) {
  let {
    sliderOptions,
    trackOptions,
    tickMarkOptions,
    thumbOptions,
    children
  } = _ref;
  const {
    size,
    clockwise
  } = sliderOptions;
  const {
    width,
    color
  } = trackOptions;
  const derivedSize = (0, _reactNativeReanimated.useDerivedValue)(() => size, [size]);
  const derivedTrackWidth = (0, _reactNativeReanimated.useDerivedValue)(() => width || derivedSize.value * 0.1, [width]);
  const derivedR = (0, _reactNativeReanimated.useDerivedValue)(() => (derivedSize.value - derivedTrackWidth.value) / 2);
  const derivedCenter = (0, _reactNativeReanimated.useDerivedValue)(() => ({
    x: derivedSize.value / 2,
    y: derivedSize.value / 2
  }));
  return /*#__PURE__*/_react.default.createElement(SliderContext.Provider, {
    value: {
      size: derivedSize,
      r: derivedR,
      clockwise,
      center: derivedCenter,
      trackWidth: derivedTrackWidth,
      trackColor: color,
      tickMarkOptions,
      thumbOptions
    }
  }, children);
}

function useSliderContext() {
  const context = (0, _react.useContext)(SliderContext);

  if (!context) {
    throw new Error('SliderContext.Provider is not found.');
  }

  return context;
}

function useTickMarkContext() {
  const context = useSliderContext();
  return context.tickMarkOptions;
}

function useThumbContext() {
  const context = useSliderContext();
  return context.thumbOptions;
}
//# sourceMappingURL=SliderContext.js.map