"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Duration = Duration;

var _react = _interopRequireDefault(require("react"));

var _reactNativeRedash = require("react-native-redash");

var _reactNativeReanimated = require("react-native-reanimated");

var _worklets = require("../../utils/worklets");

var _SliderContext = require("../../context/SliderContext");

var _Container = require("../../components/Container");

var _svg = require("../../components/svg");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Duration(_ref) {
  let {
    duration,
    filledColor,
    onChange
  } = _ref;
  const {
    center,
    clockwise
  } = (0, _SliderContext.useSliderContext)();
  const {
    total
  } = (0, _SliderContext.useTickMarkContext)();
  const {
    colors
  } = (0, _SliderContext.useThumbContext)();
  const startTheta = (0, _reactNativeReanimated.useSharedValue)((0, _worklets.amount2Theta)(duration.start, total, clockwise));
  const endTheta = (0, _reactNativeReanimated.useSharedValue)((0, _worklets.amount2Theta)(duration.end, total, clockwise));

  const onGestureActive = (_ref2, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref2;
    const {
      theta
    } = (0, _reactNativeRedash.canvas2Polar)({
      x,
      y
    }, center.value);

    if (context.target.value) {
      const {
        prev,
        curr,
        next
      } = context.target.value;
      const delta = (0, _worklets.normalize)(theta);

      if ((0, _worklets.moveable)(curr.value, next.value, delta)) {
        curr.value = delta;
      }

      if ((0, _worklets.moveable)(prev.value, curr.value, delta)) {
        curr.value = delta;
      }

      context.offset = curr.value;
    } else {
      const delta = theta - context.offset;
      startTheta.value = (0, _worklets.normalize)(startTheta.value + delta);
      endTheta.value = (0, _worklets.normalize)(endTheta.value + delta);
      context.offset = theta;
    }
  };

  const onGestureEnd = (_ref3, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref3;
    context.target.value = null;

    if (onChange) {
      (0, _reactNativeReanimated.runOnJS)(onChange)({
        start: (0, _worklets.theta2Amount)(startTheta.value, total, clockwise),
        end: (0, _worklets.theta2Amount)(endTheta.value, total, clockwise)
      });
    }
  };

  return /*#__PURE__*/_react.default.createElement(_Container.Container, {
    thetas: [startTheta, endTheta],
    onGestureActive: onGestureActive,
    onGestureEnd: onGestureEnd
  }, /*#__PURE__*/_react.default.createElement(_svg.FilledGauge, {
    startTheta: startTheta,
    endTheta: endTheta,
    color: filledColor
  }), /*#__PURE__*/_react.default.createElement(_svg.Thumb, {
    theta: startTheta,
    color: colors[0]
  }), /*#__PURE__*/_react.default.createElement(_svg.Thumb, {
    theta: endTheta,
    color: colors[1]
  }));
}
//# sourceMappingURL=Duration.js.map