import React, { createContext, useContext } from 'react';
import { useDerivedValue } from 'react-native-reanimated';
const SliderContext = /*#__PURE__*/createContext(null);
export default function SliderContextProvider(_ref) {
  let {
    sliderOptions,
    trackOptions,
    tickMarkOptions,
    thumbOptions,
    children
  } = _ref;
  const {
    size,
    clockwise
  } = sliderOptions;
  const {
    width,
    color
  } = trackOptions;
  const derivedSize = useDerivedValue(() => size, [size]);
  const derivedTrackWidth = useDerivedValue(() => width || derivedSize.value * 0.1, [width]);
  const derivedR = useDerivedValue(() => (derivedSize.value - derivedTrackWidth.value) / 2);
  const derivedCenter = useDerivedValue(() => ({
    x: derivedSize.value / 2,
    y: derivedSize.value / 2
  }));
  return /*#__PURE__*/React.createElement(SliderContext.Provider, {
    value: {
      size: derivedSize,
      r: derivedR,
      clockwise,
      center: derivedCenter,
      trackWidth: derivedTrackWidth,
      trackColor: color,
      tickMarkOptions,
      thumbOptions
    }
  }, children);
}
export function useSliderContext() {
  const context = useContext(SliderContext);

  if (!context) {
    throw new Error('SliderContext.Provider is not found.');
  }

  return context;
}
export function useTickMarkContext() {
  const context = useSliderContext();
  return context.tickMarkOptions;
}
export function useThumbContext() {
  const context = useSliderContext();
  return context.thumbOptions;
}
//# sourceMappingURL=SliderContext.js.map