import React from 'react';
import { canvas2Polar } from 'react-native-redash';
import { runOnJS, useSharedValue } from 'react-native-reanimated';
import { useSliderContext, useTickMarkContext } from '../../context/SliderContext';
import { Container } from '../../components/Container';
import { FilledGauge, Thumb } from '../../components/svg';
import { amount2Theta, normalize, theta2Amount } from '../../utils/worklets';
export function Amount(_ref) {
  let {
    amount,
    thumbColor,
    filledColor,
    onChange
  } = _ref;
  const {
    center,
    clockwise
  } = useSliderContext();
  const {
    total
  } = useTickMarkContext();
  const zeroTheta = useSharedValue(amount2Theta(0, total, clockwise));
  const theta = useSharedValue(amount2Theta(amount, total, clockwise));

  const onGestureActive = (_ref2, context) => {
    'worklet';

    var _context$target$value;

    let {
      x,
      y
    } = _ref2;

    if ((_context$target$value = context.target.value) !== null && _context$target$value !== void 0 && _context$target$value.curr) {
      const {
        theta: newTheta
      } = canvas2Polar({
        x,
        y
      }, center.value);
      const delta = newTheta - context.offset;
      theta.value = normalize(theta.value + delta);
      context.offset = newTheta;
    }
  };

  const onGestureEnd = (_ref3, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref3;
    context.target.value = null;

    if (onChange) {
      runOnJS(onChange)(theta2Amount(theta.value, total, clockwise));
    }
  };

  return /*#__PURE__*/React.createElement(Container, {
    thetas: [theta],
    onGestureActive: onGestureActive,
    onGestureEnd: onGestureEnd
  }, /*#__PURE__*/React.createElement(FilledGauge, {
    color: filledColor,
    startTheta: zeroTheta,
    endTheta: theta
  }), /*#__PURE__*/React.createElement(Thumb, {
    theta: theta,
    color: thumbColor
  }));
}
//# sourceMappingURL=Amount.js.map