import React from 'react';
import { canvas2Polar } from 'react-native-redash';
import { runOnJS, useSharedValue } from 'react-native-reanimated';
import { amount2Theta, moveable, normalize, theta2Amount } from '../../utils/worklets';
import { useSliderContext, useThumbContext, useTickMarkContext } from '../../context/SliderContext';
import { Container } from '../../components/Container';
import { FilledGauge, Thumb } from '../../components/svg';
export function Duration(_ref) {
  let {
    duration,
    filledColor,
    onChange
  } = _ref;
  const {
    center,
    clockwise
  } = useSliderContext();
  const {
    total
  } = useTickMarkContext();
  const {
    colors
  } = useThumbContext();
  const startTheta = useSharedValue(amount2Theta(duration.start, total, clockwise));
  const endTheta = useSharedValue(amount2Theta(duration.end, total, clockwise));

  const onGestureActive = (_ref2, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref2;
    const {
      theta
    } = canvas2Polar({
      x,
      y
    }, center.value);

    if (context.target.value) {
      const {
        prev,
        curr,
        next
      } = context.target.value;
      const delta = normalize(theta);

      if (moveable(curr.value, next.value, delta)) {
        curr.value = delta;
      }

      if (moveable(prev.value, curr.value, delta)) {
        curr.value = delta;
      }

      context.offset = curr.value;
    } else {
      const delta = theta - context.offset;
      startTheta.value = normalize(startTheta.value + delta);
      endTheta.value = normalize(endTheta.value + delta);
      context.offset = theta;
    }
  };

  const onGestureEnd = (_ref3, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref3;
    context.target.value = null;

    if (onChange) {
      runOnJS(onChange)({
        start: theta2Amount(startTheta.value, total, clockwise),
        end: theta2Amount(endTheta.value, total, clockwise)
      });
    }
  };

  return /*#__PURE__*/React.createElement(Container, {
    thetas: [startTheta, endTheta],
    onGestureActive: onGestureActive,
    onGestureEnd: onGestureEnd
  }, /*#__PURE__*/React.createElement(FilledGauge, {
    startTheta: startTheta,
    endTheta: endTheta,
    color: filledColor
  }), /*#__PURE__*/React.createElement(Thumb, {
    theta: startTheta,
    color: colors[0]
  }), /*#__PURE__*/React.createElement(Thumb, {
    theta: endTheta,
    color: colors[1]
  }));
}
//# sourceMappingURL=Duration.js.map