import React from 'react';
import { canvas2Polar } from 'react-native-redash';
import { runOnJS, useSharedValue } from 'react-native-reanimated';
import { Container } from '../../components/Container';
import { FilledGauge, Thumb } from '../../components/svg';
import { moveable, normalize, percent2Theta, theta2Percent } from '../../utils/worklets';
import { useSliderContext, useThumbContext } from '../../context/SliderContext';
export function Percent(_ref) {
  let {
    percents,
    filledColor,
    onChange
  } = _ref;
  const {
    center
  } = useSliderContext();
  const {
    colors
  } = useThumbContext();
  const thetas = percents.reduce((acc, cur, index) => {
    var _acc;

    return [...acc, useSharedValue(percent2Theta(cur, (_acc = acc[index - 1]) === null || _acc === void 0 ? void 0 : _acc.value))];
  }, []);

  const onGestureActive = (_ref2, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref2;
    const {
      theta
    } = canvas2Polar({
      x,
      y
    }, center.value);

    if (context.target.value) {
      const {
        prev,
        curr,
        next
      } = context.target.value;
      const delta = normalize(theta);

      if (moveable(curr.value, next.value, delta)) {
        curr.value = delta;
      }

      if (moveable(prev.value, curr.value, delta)) {
        curr.value = delta;
      }

      context.offset = curr.value;
    } else {
      if (context.offset) {
        const delta = theta - context.offset;
        thetas.forEach(t => t.value = normalize(t.value + delta));
        context.offset = theta;
      }
    }
  };

  const onGestureEnd = (_ref3, context) => {
    'worklet';

    let {
      x,
      y
    } = _ref3;
    context.target.value = null;

    if (onChange) {
      runOnJS(onChange)(thetas.reduce((acc, cur, index, arr) => {
        const prev = arr[index - 1] || arr[arr.length - 1];
        acc.push(theta2Percent(cur.value, prev.value));
        return acc;
      }, []));
    }
  };

  return /*#__PURE__*/React.createElement(Container, {
    thetas: thetas,
    onGestureActive: onGestureActive,
    onGestureEnd: onGestureEnd
  }, thetas.reduce((acc, cur, index, arr) => {
    const prev = arr[index - 1] || arr[arr.length - 1];
    acc.push( /*#__PURE__*/React.createElement(FilledGauge, {
      key: index,
      startTheta: prev,
      endTheta: cur,
      color: filledColor[index]
    }));
    return acc;
  }, []), thetas.map((theta, index) => /*#__PURE__*/React.createElement(Thumb, {
    key: index,
    theta: theta,
    color: colors[index]
  })));
}
//# sourceMappingURL=Percent.js.map